@@ -22,11 +22,13 @@
 
 #include <QAbstractListModel>
 
+#include "plottingenums.h"
 #include "analitzaplot/analitzaplotexport.h"
 
 namespace Analitza
 {
 class PlotItem;
+class Variables;
 
 /**
  * \class PlotsModel
@@ -46,7 +48,8 @@ friend class PlotItem;
 public:
     enum Roles {
         DimensionRole = Qt::UserRole+1,
-        PlotRole
+        PlotRole,
+        DescriptionRole
     };
     
     PlotsModel(QObject * parent = 0);
@@ -59,6 +62,7 @@ public:
     virtual int rowCount(const QModelIndex & parent = QModelIndex()) const;
     virtual int columnCount(const QModelIndex& parent) const;
     virtual bool removeRows(int row, int count, const QModelIndex & parent = QModelIndex());
+    QHash<int, QByteArray> roleNames() const override;
 
     void addPlot(PlotItem *it);
     void updatePlot(int row, PlotItem* it);
@@ -71,6 +75,11 @@ public:
 
     void setResolution(int res);
 
+    /**
+     * Helper method to help easily add elements to the model
+     */
+    QStringList addFunction(const QString& expression, Analitza::Dimension dim, Analitza::Variables* vars);
+
 protected:
     void emitChanged(PlotItem* it);
 
