@@ -38,7 +38,7 @@
 
 using namespace Analitza;
 
-Q_DECLARE_METATYPE(PlotItem*);
+Q_DECLARE_METATYPE(PlotItem*)
 
 // #define DEBUG_GRAPH
 
@@ -56,8 +56,9 @@ const double Plotter2D::ZoomOutFactor = 2*1.03; // 2 x (regular mouse wheel back
 struct Plotter2D::GridInfo
 {
     double inc, xini, yini, xend, yend;
+    int incLabelSkip;
     // sub5 flag is used for draw sub 5 intervals instead of 4
-    bool sub5; // true if inc=5*pow(10,n) (so, in this case, we draw 5 sub intervals, not 4)
+    int subinc; // true if inc=5*pow(10,n) (so, in this case, we draw 5 sub intervals, not 4)
     // we need scale for ticks, and for labels, thicks can be minor, labels no: so 
     // this is necessary for minor ticks and for minir grid (but not for labels, so when draw labels we need )
     int nxiniticks, nyiniticks, nxendticks, nyendticks; // nxini = floor(viewport.left()/inc), so xini is nxini*inc ... and so on
@@ -127,63 +128,19 @@ const Plotter2D::GridInfo Plotter2D::getGridInfo() const
 {
     GridInfo ret;
     
-    const double currvpsize = viewport.width();
-    
-    static double oldvpsize = currvpsize;
-    static double inc = (m_scaleMode == Linear) ? 1.0 : M_PI; // by default 1.0 (with Linear scale) //TODO log scale
-    static double zoomoutacum = 0.0;
-    static int zoomcount = -1;
-    static bool sub5 = false;
-    
-    float zoomfactor = 2;
-    
-    if (oldvpsize < currvpsize) // zoom-out
-    {
-        zoomoutacum += currvpsize - oldvpsize;
-        
-        if (2*zoomfactor*inc <= zoomoutacum)
-        {
-            zoomoutacum = 0.0;
-            
-            if ((zoomcount) % 3 == 0)
-                    sub5 = true;
-                else
-                    sub5 = false;
-            
-            if (zoomcount % 3 == 0)
-                inc *= 2.5; // 5*h/2
-            else
-                inc *= 2; //2*h
-            
-            ++zoomcount;
-        }
+    if (m_scaleMode == Linear) {
+        const double val = log10(qMax(viewport.width(), -viewport.height()));
+        const double diff = val-floor(val);
+        const double magnitude = pow(10, floor(val)-1);
+
+        ret.inc = magnitude;
+        ret.incLabelSkip = diff < 0.5 ? 1 : 3;
+    } else {
+        ret.inc = M_PI;
+        ret.incLabelSkip = 1;
     }
-    else
-        if (oldvpsize > currvpsize) // zoom-in
-        {
-            if (currvpsize < 2.0)
-                zoomfactor = 1;
-            
-            if (currvpsize <= 2*inc*zoomfactor)
-            {
-                --zoomcount;
-                
-                if ((zoomcount - 1) % 3 == 0)
-                    sub5 = true;
-                else
-                    sub5 = false;
-                
-                if (zoomcount % 3 == 0)
-                    inc *= 0.4; // 2*h/5
-                else
-                    inc *= 0.5; // h/2
-            }
-        }
-    
-    oldvpsize = currvpsize;
-    
-    ret.inc = inc;
-    ret.sub5 = sub5;
+
+    ret.subinc = 4;
     
     ret.nxinilabels = std::floor(viewport.left()/ret.inc);
     ret.nyinilabels = std::floor(viewport.bottom()/ret.inc);
@@ -195,8 +152,8 @@ const Plotter2D::GridInfo Plotter2D::getGridInfo() const
     ret.xend = ret.nxendlabels*ret.inc;
     ret.yend = ret.nyendlabels*ret.inc;
 
-    bool drawminor = m_showMinorGrid || m_showMinorTicks;
-    double nfactor = drawminor ? (sub5? 5 : 4) : 1;
+    const bool drawminor = m_showMinorGrid || m_showMinorTicks;
+    const double nfactor = drawminor ? ret.subinc : 1;
     
     ret.nxiniticks = nfactor*ret.nxinilabels;
     ret.nyiniticks = nfactor*ret.nyinilabels;
@@ -249,16 +206,16 @@ void Plotter2D::drawMainAxes(QPainter* painter) const
     painter->setPen(axesPen);
     painter->setBrush(axesPen.color());
     
-    int startAngleX = 150*16;
-    int startAngleY = 240*16;
-    int spanAngle = 60*16;
-    QPointF Xright(this->width(), center.y());
-    QPointF Ytop(center.x(), 0.);
+    const int startAngleX = 150*16;
+    const int startAngleY = 240*16;
+    const int spanAngle = 60*16;
+    const QPointF Xright(this->width(), center.y());
+    const QPointF Ytop(center.x(), 0.);
     const double arrowWidth=15., arrowHeight=4.;
-    QPointF dpx(arrowWidth, arrowHeight);
-    QPointF dpy(arrowHeight, arrowWidth);
-    QRectF rectX(Xright+dpx, Xright-dpx);
-    QRectF rectY(Ytop+dpy, Ytop-dpy);
+    const QPointF dpx(arrowWidth, arrowHeight);
+    const QPointF dpy(arrowHeight, arrowWidth);
+    const QRectF rectX(Xright+dpx, Xright-dpx);
+    const QRectF rectY(Ytop+dpy, Ytop-dpy);
 
     if (m_showAxes&Qt::Horizontal)
     {
@@ -303,9 +260,9 @@ const QString Plotter2D::computeAngleLabelByFrac(unsigned int n, unsigned int d)
     {
         case Radian:
         {
-            s = (n==1) ? QStringLiteral("") : QString::number(n);
+            s = (n==1) ? QString() : QString::number(n);
             s += PiSymbol;
-            s += (d==1) ? QStringLiteral("") : "/"+QString::number(d);
+            s += (d==1) ? QString() : '/'+QString::number(d);
         }
         break;
         case Degree: s = QString::number(radiansToDegrees(n*M_PI/d))+DegreeSymbol; break;
@@ -338,21 +295,17 @@ void Plotter2D::drawCartesianTickLabels(QPainter* painter, const Plotter2D::Grid
 {
     Q_ASSERT(axis == XAxis || axis == Analitza::YAxis);
     
-    static const unsigned short axisxseparation = 16; // distance between tick text and x-axis 
-    static const unsigned short axisyseparation = 4; // distance between tick text and y-axis
-    static const unsigned short textposcorrection = 2;
     const bool isxaxis = (axis == XAxis);
-    const double hfmhalf = isxaxis ? 0.0 : painter->fontMetrics().height()*0.5;
+    const double fontHeight = painter->fontMetrics().height();
     
     const bool incbig = (M_PI <= gridinfo.inc);
     const unsigned int bigstep = std::floor(gridinfo.inc/M_PI);
     const unsigned int step = std::ceil(M_PI/gridinfo.inc);
     
     QString s;
-    QPointF p;
-    
-    int from = (axis == Analitza::XAxis) ? gridinfo.nxinilabels : gridinfo.nyinilabels;
-    int to = (axis == Analitza::XAxis) ? gridinfo.nxendlabels : gridinfo.nyendlabels;
+
+    const int from = (axis == Analitza::XAxis) ? gridinfo.nxinilabels : gridinfo.nyinilabels;
+    const int to = (axis == Analitza::XAxis) ? gridinfo.nxendlabels : gridinfo.nyendlabels;
     
     painter->save();
     QFont tickFont = QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont);
@@ -360,14 +313,13 @@ void Plotter2D::drawCartesianTickLabels(QPainter* painter, const Plotter2D::Grid
     painter->setPen(QPen(QPalette().text().color()));
     for (int i = from; i <= to; ++i)
     {
-        if (i == 0) continue;
+        if (i == 0 || i%gridinfo.incLabelSkip!=0) continue;
         
         double newval = i*gridinfo.inc;
         
-        if (isxaxis)
-            p = toWidget(QPointF(newval, 0.0));
-        else
-            p = toWidget(QPointF(0.0, newval));
+        const QPointF p = isxaxis
+            ? toWidget(QPointF(newval, 0.0))
+            : toWidget(QPointF(0.0, newval));
         
         switch (m_scaleMode)
         {
@@ -385,17 +337,16 @@ void Plotter2D::drawCartesianTickLabels(QPainter* painter, const Plotter2D::Grid
                     const QPair<unsigned int, unsigned int> frac = simplifyFraction(qAbs(i), step);
                     
                     s += computeAngleLabelByFrac(frac.first, frac.second);
-                }                
+                }
             }
             break;
         }
         
-        int swidth = painter->fontMetrics().width(s);
-        
+        const int swidth = painter->fontMetrics().width(s);
         if (isxaxis)
-            painter->drawText(p.x()-swidth/2+textposcorrection, p.y()+axisxseparation, s);
+            painter->drawText(p.x() - swidth/2, p.y()+fontHeight, s);
         else
-            painter->drawText(p.x()-swidth-axisyseparation, p.y()+hfmhalf-textposcorrection, s);
+            painter->drawText(p.x() - swidth - fontHeight/2, p.y()+fontHeight/2, s);
     }
     painter->restore();
 }
@@ -407,7 +358,7 @@ void Plotter2D::drawPolarTickLabels(QPainter* painter, const Plotter2D::GridInfo
     painter->setPen(m_gridColor);
     
     //TODO if minor
-    const double newinc = gridinfo.inc/(gridinfo.sub5 ? 5 : 4); // inc with sub intervals
+    const double newinc = gridinfo.inc/(gridinfo.subinc); // inc with sub intervals
     
     //x
     // we assume 0 belongs to interval [gridinfo.xini, gridinfo.xend]
@@ -511,7 +462,7 @@ void Plotter2D::drawCircles(QPainter* painter, const GridInfo& gridinfo, GridSty
     const QPen gridPen(m_gridColor);
     const QPen subGridPen(computeSubGridColor());
 
-    const unsigned short nsubinc = gridinfo.sub5 ? 5 : 4; // count for draw sub intervals
+    const unsigned short nsubinc = gridinfo.subinc; // count for draw sub intervals
     const bool drawminor = m_showMinorGrid || m_showMinorTicks;
     const double inc = drawminor ? gridinfo.inc/nsubinc : gridinfo.inc; // if show minor, then inc with sub intervals
     
@@ -536,25 +487,19 @@ void Plotter2D::drawCircles(QPainter* painter, const GridInfo& gridinfo, GridSty
                 painter->setPen(gridPen);
                 painter->drawEllipse(er);
             }
-            else // sub intervals
+            else if (m_showMinorGrid)// sub intervals
             {
-                if (m_showMinorGrid)
-                {
-                    painter->setPen(subGridPen);
-                    painter->drawEllipse(er);
-                }
+                painter->setPen(subGridPen);
+                painter->drawEllipse(er);
             }
         }
         
         if (m_showPolarAxis) // draw polar rays
         {
             double h = Pi12; // 2pi/(Pi/12) = 24 steps/turns
-            double t = h;
             const double r = std::abs(until); // radius
             const QPointF origin = toWidget(QPointF(0,0));
             
-            QPointF p;
-            
             int k = 1;
             unsigned int alternatesubgridcount = 2;
             unsigned int dontdrawataxiscount = 5;
@@ -564,31 +509,28 @@ void Plotter2D::drawCircles(QPainter* painter, const GridInfo& gridinfo, GridSty
             if (!viewport.contains(QPointF(0.0, 0.0)))
             {
                 h = Pi36; // 2pi/(Pi/36) = 72 steps
-                t = h;
                 steps = 72; // or turns
                 alternatesubgridcount = 3;
                 dontdrawataxiscount = 17;
             }
             
+            double t = h;
             for (uint j = 1; j <= steps; ++j, ++k, t += h)
             {
                 if (j % alternatesubgridcount == 0)
                     painter->setPen(gridPen);
-                else
+                else if (m_showMinorGrid)
                 {
-                    if (!m_showMinorGrid)
-                        continue;
-                    
                     painter->setPen(subGridPen);
-                }
-                
-                p = toWidget(QPointF(r*std::cos(t), r*std::sin(t)));
-                painter->drawLine(origin, p);
-                
-                if (k % dontdrawataxiscount == 0) // avoid draw the ray at 0,pi/2,pi,3pi/2
-                {
-                    t += h;
-                    ++j;
+
+                    QPointF p = toWidget(QPointF(r*std::cos(t), r*std::sin(t)));
+                    painter->drawLine(origin, p);
+
+                    if (k % dontdrawataxiscount == 0) // avoid draw the ray at 0,pi/2,pi,3pi/2
+                    {
+                        t += h;
+                        ++j;
+                    }
                 }
             }
         }
@@ -598,48 +540,35 @@ void Plotter2D::drawCircles(QPainter* painter, const GridInfo& gridinfo, GridSty
     if (m_showTickLabels & Qt::Horizontal)
     {
         painter->setPen(textPen);
-        QPointF p;
-        int i = 0;
-        
         const QPointF yoffset(0.,-3.);
         
-        for (int j = gridinfo.nxiniticks; j < gridinfo.nxendticks; ++j, ++i)
+        for (int j = gridinfo.nxiniticks, i = 0; j < gridinfo.nxendticks; ++j, ++i)
         {
             if (j == 0) continue;
             
-            double x = j*inc;
-            
-            p = toWidget(QPointF(x, 0.));
+            const double x = j*inc;
+            const QPointF p = toWidget(QPointF(x, 0.));
 
-            if ((i % nsubinc == 0) || !drawminor)
+            if ((i % nsubinc == 0) || !drawminor || m_showMinorTicks)
                 painter->drawLine(p, p+yoffset);
-            else // sub intervals
-                if (m_showMinorTicks)
-                    painter->drawLine(p, p+yoffset);
         }
     }
     
     if (m_showTickLabels & Qt::Vertical)
     {
         painter->setPen(textPen);
-        QPointF p;
-        int i = 0;
-        
         const QPointF xoffset(3.,0.);
         
-        for (int j = gridinfo.nyiniticks; j < gridinfo.nyendticks; ++j, ++i)
+        for (int j = gridinfo.nyiniticks, i = 0; j < gridinfo.nyendticks; ++j, ++i)
         {
             if (j == 0) continue;
             
-            double y = j*inc;
+            const double y = j*inc;
             
-            p = toWidget(QPointF(0., y));
+            const QPointF p = toWidget(QPointF(0., y));
             
-            if ((i % nsubinc == 0) || !(m_showMinorGrid || m_showMinorTicks))
+            if ((i % nsubinc == 0) || !(m_showMinorGrid || m_showMinorTicks) || m_showMinorTicks)
                 painter->drawLine(p, p+xoffset);
-            else // sub intervals
-                if (m_showMinorTicks)
-                    painter->drawLine(p, p+xoffset);
         }
     }
     //END draw ticks
@@ -655,37 +584,28 @@ void Plotter2D::drawSquares(QPainter* painter, const GridInfo& gridinfo, GridSty
     const QPen gridPenBold(gridPen.brush(), 2);
     const QPen subGridPenBold(subGridPen.brush(), gridPenBold.widthF());
     
-    const unsigned short nsubinc = gridinfo.sub5 ? 5:4; // count for draw sub intervals
+    const unsigned short nsubinc = gridinfo.subinc; // count for draw sub intervals
     const bool drawminor = m_showMinorGrid || m_showMinorTicks;
     const double inc = drawminor? gridinfo.inc/nsubinc : gridinfo.inc; // if show minor, then inc with sub intervals
     
-    QPointF p;
-    int i = 0;
-    
-    for (int n = gridinfo.nxiniticks; n < gridinfo.nxendticks; ++n, ++i)
+    for (int n = gridinfo.nxiniticks, i = 0; n < gridinfo.nxendticks; ++n, ++i)
     {
         if (n == 0) continue;
         
-        double x = n*inc;
+        const double x = n*inc;
+        const QPointF p = toWidget(QPointF(x, 0.));
         
-        p = toWidget(QPointF(x, 0.));
-        
-        if (m_showGrid && (gridStyle == Crosses))
+        if (m_showGrid && gridStyle == Crosses)
         {
-            QPointF py;
-            int k = 0;
-            
             const double crossside = 5;
-            
-            for (int j = gridinfo.nyiniticks; j < gridinfo.nyendticks; ++j, ++k)
+            const double centx = p.x();
+
+            for (int j = gridinfo.nyiniticks, k = 0; j < gridinfo.nyendticks; ++j, ++k)
             {
                 if (j == 0) continue;
-                
-                double y = j*inc;
-                
-                py = toWidget(QPointF(0., y));
-                
-                const double centx = p.x();
+
+                const double y = j*inc;
+                const QPointF py = toWidget(QPointF(0., y));
                 const double centy = py.y();
                 
                 if (((i % nsubinc == 0) && (k % nsubinc == 0)) || !drawminor) // intervals
@@ -694,24 +614,22 @@ void Plotter2D::drawSquares(QPainter* painter, const GridInfo& gridinfo, GridSty
                     painter->drawLine(QPointF(centx-crossside, centy), QPointF(centx+crossside, centy)); // horizontal
                     painter->drawLine(QPointF(centx, centy-crossside), QPointF(centx, centy+crossside)); // vertical
                 }
-                else // sub intervals
-                    if (m_showMinorGrid)
-                    {
-                        painter->setPen(subGridPenBold);
-                        painter->drawLine(QPointF(centx-crossside, centy), QPointF(centx+crossside, centy)); // horizontal
-                        painter->drawLine(QPointF(centx, centy-crossside), QPointF(centx, centy+crossside)); // vertical
-                    }
+                else if (m_showMinorGrid)// sub intervals
+                {
+                    painter->setPen(subGridPenBold);
+                    painter->drawLine(QPointF(centx-crossside, centy), QPointF(centx+crossside, centy)); // horizontal
+                    painter->drawLine(QPointF(centx, centy-crossside), QPointF(centx, centy+crossside)); // vertical
+                }
             }
         }
         
         if ((i % nsubinc == 0) || !drawminor) // intervals
         {
-            if (m_showGrid)
-                if (gridStyle == Squares || gridStyle == VerticalLines)
-                {
-                    painter->setPen(gridPen);
-                    painter->drawLine(QPointF(p.x(), height()), QPointF(p.x(), 0.)); 
-                }
+            if (m_showGrid && (gridStyle == Squares || gridStyle == VerticalLines))
+            {
+                painter->setPen(gridPen);
+                painter->drawLine(QPointF(p.x(), height()), QPointF(p.x(), 0.));
+            }
             
             if ((m_showTicks & Qt::Horizontal))
             {
@@ -721,12 +639,11 @@ void Plotter2D::drawSquares(QPainter* painter, const GridInfo& gridinfo, GridSty
         }
         else // sub intervals
         {
-            if (m_showGrid && m_showMinorGrid)
-                if (gridStyle == Squares || gridStyle == VerticalLines)
-                {
-                    painter->setPen(subGridPen);
-                    painter->drawLine(QPointF(p.x(), height()), QPointF(p.x(), 0.)); 
-                }
+            if (m_showGrid && m_showMinorGrid && (gridStyle == Squares || gridStyle == VerticalLines))
+            {
+                painter->setPen(subGridPen);
+                painter->drawLine(QPointF(p.x(), height()), QPointF(p.x(), 0.));
+            }
             
             if ((m_showTicks & Qt::Horizontal) && m_showMinorTicks)
             {
@@ -736,24 +653,20 @@ void Plotter2D::drawSquares(QPainter* painter, const GridInfo& gridinfo, GridSty
         }
     }
     
-    i = 0;
-    
-    for (int j = gridinfo.nyiniticks; j < gridinfo.nyendticks; ++j, ++i)
+    for (int j = gridinfo.nyiniticks, i = 0; j < gridinfo.nyendticks; ++j, ++i)
     {
         if (j == 0) continue;
         
-        double y = j*inc;
-        
-        p = toWidget(QPointF(0., y));
+        const double y = j*inc;
+        const QPointF p = toWidget(QPointF(0., y));
         
         if ((i % nsubinc == 0) || !drawminor) // intervals
         {
-            if (m_showGrid)
-                if (gridStyle == Squares || gridStyle == HorizontalLines)
-                {
-                    painter->setPen(gridPen);
-                    painter->drawLine(QPointF(0., p.y()), QPointF(width(), p.y()));
-                }
+            if (m_showGrid && (gridStyle == Squares || gridStyle == HorizontalLines))
+            {
+                painter->setPen(gridPen);
+                painter->drawLine(QPointF(0., p.y()), QPointF(width(), p.y()));
+            }
             
             if ((m_showTicks & Qt::Horizontal))
             {
@@ -763,12 +676,11 @@ void Plotter2D::drawSquares(QPainter* painter, const GridInfo& gridinfo, GridSty
         }
         else // sub intervals
         {
-            if (m_showGrid && m_showMinorGrid)
-                if (gridStyle == Squares || gridStyle == HorizontalLines)
-                    {
-                        painter->setPen(subGridPen);
-                        painter->drawLine(QPointF(0., p.y()), QPointF(width(), p.y()));
-                    }
+            if (m_showGrid && m_showMinorGrid && (gridStyle == Squares || gridStyle == HorizontalLines))
+            {
+                painter->setPen(subGridPen);
+                painter->drawLine(QPointF(0., p.y()), QPointF(width(), p.y()));
+            }
             
             if ((m_showTicks & Qt::Horizontal) && m_showMinorTicks)
             {
@@ -844,7 +756,7 @@ void Plotter2D::drawFunctions(QPaintDevice *qpd)
 #endif
         for(unsigned int j=0; j<pointsCount; ++j)
         {
-            QPointF act=toWidget(vect.at(j));
+            const QPointF act = toWidget(vect.at(j));
 
 //          qDebug() << "xxxxx" << act << ultim << qIsNaN(act.y()) << qIsNaN(ultim.y());
             if(qIsInf(act.y()) && !qIsNaN(act.y())) qDebug() << "trying to plot from a NaN value" << act << ultim;
@@ -1106,3 +1018,9 @@ void Plotter2D::zoomOut(bool repaint)
 {
     scaleViewport(ZoomOutFactor, QPoint(m_size.width()*0.5, m_size.height()*0.5), repaint);
 }
+
+void Plotter2D::setShowMinorGrid(bool mt)
+{
+    m_showMinorGrid=mt;
+    forceRepaint();
+}
