@@ -28,8 +28,13 @@
 
 #include <cmath>
 #include <QDebug>
-#include <KLocalizedString>
-#include <KColorUtils>
+#include <QFile>
+
+#ifdef __APPLE__
+#include <OpenGL/gl.h>
+#else
+#include <GL/gl.h>
+#endif
 
 #if defined(HAVE_IEEEFP_H)
 #include <ieeefp.h>
@@ -39,7 +44,16 @@
 using namespace std;
 using namespace Analitza;
 
-Q_DECLARE_METATYPE(PlotItem*);
+Q_DECLARE_METATYPE(PlotItem*)
+
+void qgluPerspective(GLdouble fovy, GLdouble aspect, GLdouble zNear, GLdouble zFar)
+{
+    const GLdouble ymax = zNear * tan(fovy * M_PI / 360.0);
+    const GLdouble ymin = -ymax;
+    const GLdouble xmin = ymin * aspect;
+    const GLdouble xmax = ymax * aspect;
+    glFrustum(xmin, xmax, ymin, ymax, zNear, zFar);
+}
 
 const GLubyte Plotter3D::XAxisArrowColor[] = {250 -1 , 1, 1};
 const GLubyte Plotter3D::YAxisArrowColor[] = {1, 255 - 1, 1};
@@ -150,14 +164,14 @@ inline void glMultMatrix(const GLdouble *m) { glMultMatrixd(m); }
 void Plotter3D::drawPlots()
 {
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-    
+
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
-    gluPerspective(m_scale, m_viewport.width()/m_viewport.height(), 0.1, 3000);
+    qgluPerspective(m_scale, m_viewport.width()/m_viewport.height(), 0.1, 3000);
 
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
-    glMultMatrix(m_rot.constData());
+    glMultMatrixf(m_rot.data());
 
     // Object Drawing :
     glCallList(m_sceneObjects.value(Axes));
@@ -178,7 +192,7 @@ void Plotter3D::drawPlots()
             case InvalidAxis:
                 break;
         }
-    
+
     glEnable(GL_LIGHTING);
     glEnable(GL_LIGHT0);
 
@@ -199,9 +213,7 @@ void Plotter3D::drawPlots()
         return ;
     }
 
-    //NOTE si esto pasa entonces quiere decir que el proxy empezado a filtrar otros items
-    // y si es asi borro todo lo que esta agregado al la memoria de la tarjeta
-    //esto se hace pues m_itemGeometries es una copia del estado actual de model
+    //clean up everything if the model  and itemGeometries are not in sync
     if (m_model->rowCount() != m_itemGeometries.count())
     {
         foreach (PlotItem *item, m_itemGeometries.keys())
@@ -211,11 +223,9 @@ void Plotter3D::drawPlots()
         }
     }
 
-    /// luego paso a verificar el map de display list no este vacio ... si lo esta lo reconstruyo
-
     if (m_itemGeometries.isEmpty())
     {
-        //NOTE no llamar a ninguna funcion que ejucute un updategl, esto para evitar una recursividad
+        // don't call any function that calls updateGL or we'll go into an infinite recursion
         for (int i = 0; i < m_model->rowCount(); ++i) {
             PlotItem* item = dynamic_cast<Surface*>(itemAt(i));
 
@@ -238,7 +248,7 @@ void Plotter3D::drawPlots()
 
         if (SpaceCurve *curv = dynamic_cast<SpaceCurve*>(item))
         {
-            
+
             const QVector<QVector3D> points = curv->points();
             glBegin(GL_LINES);
 
@@ -248,47 +258,17 @@ void Plotter3D::drawPlots()
                 glVertex3d(points[i].x(), points[i].y(), points[i].z());
                 glVertex3d(points[i+1].x(), points[i+1].y(), points[i+1].z());
             }
-
             glEnd();
-
-//             glBindBuffer(GL_ARRAY_BUFFER, m_itemGeometries.value(curv).second);
-//             glVertexPointer(3, GL_DOUBLE, 0, 0);
-//             glNormalPointer(GL_DOUBLE, sizeof(double)*3, 0);
-// 
-//             glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_itemGeometries.value(curv).first);
-// 
-//             //BEGIN draw
-//             // start to render polygons
-//             glEnableClientState(GL_NORMAL_ARRAY);
-//             glEnableClientState(GL_VERTEX_ARRAY);
-// 
-//             glDrawElements(GL_LINES, indexes.size(), GL_UNSIGNED_INT, 0);
-// 
-//             fcolor[0] = 0; fcolor[1] = 0; fcolor[2] = 0; fcolor[3] = 1;
-//             glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, fcolor);
-//             glMaterialfv(GL_BACK, GL_AMBIENT_AND_DIFFUSE, fcolor);
-//             glDrawElements(GL_POINTS, indexes.size(), GL_UNSIGNED_INT, 0);
-//             
-//             glDisableClientState(GL_VERTEX_ARRAY);  // disable vertex arrays
-//             glDisableClientState(GL_NORMAL_ARRAY);  // disable normal arrays
-//             //END draw
-//             
-//             // it is good idea to release VBOs with ID 0 after use.
-//             // Once bound with 0, all pointers in gl*Pointer() behave as real
-//             // pointer, so, normal vertex array operations are re-activated
-//             glBindBuffer(GL_ARRAY_BUFFER, 0);
-//             glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0);
-            
         }
-        else if (Surface *surf = dynamic_cast<Surface*>(item)) 
+        else if (Surface *surf = dynamic_cast<Surface*>(item))
         {
             //NOTE
             //los indices empeizan en cero solo se puede tener un solo array bufer cuando se usa vbo
             //por eso en el array buffer se ponen los datos de lops vertices y de las normales
-            
+
             glBindBuffer(GL_ARRAY_BUFFER, m_itemGeometries.value(surf).second);
-            glVertexPointer(3, GL_DOUBLE, 0, 0);
-            glNormalPointer(GL_DOUBLE, sizeof(double)*3, 0);
+            glVertexPointer(3, GL_FLOAT, 0, 0);
+            glNormalPointer(GL_FLOAT, sizeof(float)*3, 0);
 
             glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_itemGeometries.value(surf).first);
 
@@ -307,7 +287,7 @@ void Plotter3D::drawPlots()
             glDisableClientState(GL_VERTEX_ARRAY);  // disable vertex arrays
             glDisableClientState(GL_NORMAL_ARRAY);  // disable normal arrays
             //END draw
-            
+
             // it is good idea to release VBOs with ID 0 after use.
             // Once bound with 0, all pointers in gl*Pointer() behave as real
             // pointer, so, normal vertex array operations are re-activated
@@ -323,6 +303,84 @@ void Plotter3D::drawPlots()
     glDisable(GL_LIGHT0);
 }
 
+template <typename T>
+static QByteArray fromNumbers(const QVector<T>& input)
+{
+    QByteArray ret;
+    foreach(qreal r, input) {
+        ret += QByteArray::number(r)+QByteArrayLiteral(" ");
+    }
+    ret.chop(1);
+    return ret;
+}
+
+static QByteArray fromNumbers(const QVector<QVector3D>& input)
+{
+    QByteArray ret;
+    foreach(const QVector3D &r, input) {
+        ret += QByteArray::number(r.x())+QByteArrayLiteral(" ");
+        ret += QByteArray::number(r.y())+QByteArrayLiteral(" ");
+        ret += QByteArray::number(r.z())+QByteArrayLiteral(" ");
+    }
+    ret.chop(1);
+    return ret;
+}
+
+static QVector<int> makeTriangles(const QVector<uint>& input)
+{
+    QVector<int> ret;
+    int i = 0;
+    foreach(uint val, input) {
+        ret += val;
+        if(i==2) {
+            ret += -1;
+            i = 0;
+        } else
+            ++i;
+    }
+    ret += -1;
+    return ret;
+}
+
+void Plotter3D::exportSurfaces(const QString& path) const
+{
+    QFile f(path);
+    bool b = f.open(QIODevice::WriteOnly | QIODevice::Text);
+    Q_ASSERT(b);
+    f.write(QByteArrayLiteral("<?xml version='1.0' encoding='UTF-8'?>\n"
+    "<!DOCTYPE X3D PUBLIC 'ISO//Web3D//DTD X3D 3.2//EN' 'http://www.web3d.org/specifications/x3d-3.2.dtd'>\n"
+    "<X3D profile='Interchange' version='3.2' xmlns:xsd='http://www.w3.org/2001/XMLSchema-instance' "
+        "xsd:noNamespaceSchemaLocation='http://www.web3d.org/specifications/x3d-3.2.xsd'>\n"
+        "<Scene>\n"));
+    for (int i = 0; i < m_model->rowCount(); ++i)
+    {
+        PlotItem *item = itemAt(i);
+
+        Surface *surf = dynamic_cast<Surface*>(item);
+        if (!surf || !surf->isVisible())
+            continue;
+
+        f.write(QByteArrayLiteral(
+            "<Shape>\n"
+                "<Appearance><Material diffuseColor='1 0 0' specularColor='0.8 0.7 0.5'/></Appearance>\n"
+                "<IndexedFaceSet solid='false' normalPerVertex='false' coordIndex='"));
+        f.write(fromNumbers(makeTriangles(surf->indexes())));
+        f.write(QByteArrayLiteral("'>\n"
+                    "<Coordinate point='"));
+        f.write(fromNumbers(surf->vertices()));
+        f.write(QByteArrayLiteral("'/>\n"
+        "<Normal vector='"));
+        f.write(fromNumbers(surf->normals()));
+        f.write(QByteArrayLiteral(
+                "'/>\n"
+                "</IndexedFaceSet>\n"
+            "</Shape>\n"));
+    }
+    f.write(QByteArrayLiteral(
+        "</Scene>\n"
+    "</X3D>\n"));
+}
+
 void Plotter3D::updatePlots(const QModelIndex & parent, int s, int e)
 {
     Q_ASSERT(!parent.isValid());
@@ -343,7 +401,7 @@ void Plotter3D::updatePlots(const QModelIndex & parent, int s, int e)
         return ;
     }
 
-    
+
     for(int i=s; i<=e; i++) {
         PlotItem *item = itemAt(i);
 
@@ -352,7 +410,7 @@ void Plotter3D::updatePlots(const QModelIndex & parent, int s, int e)
 
         deleteVBO(m_itemGeometries.value(item).first);
         deleteVBO(m_itemGeometries.value(item).second);
-        
+
         if (item->isVisible()) {
             //         addFuncs(QModelIndex(), s.row(), s.row());
             //igual no usar addFuncs sino la funcion interna pues no actualiza los items si tienen data
@@ -386,7 +444,7 @@ void Plotter3D::setModel(QAbstractItemModel* f)
 void Plotter3D::setPlottingFocusPolicy(PlottingFocusPolicy fp)
 {
     m_plottingFocusPolicy = fp;
-    
+
     for (int i = 0; i < m_itemGeometries.size(); ++i)
     {
         deleteVBO(m_itemGeometries.value(itemAt(i)).first);
@@ -396,7 +454,7 @@ void Plotter3D::setPlottingFocusPolicy(PlottingFocusPolicy fp)
     updatePlots(QModelIndex(), 0, m_model->rowCount()-1);
 }
 
-void Plotter3D::scale(GLdouble factor)
+void Plotter3D::scale(qreal factor)
 {
     m_scale = qBound(1., factor*m_scale, 140.);
     renderGL();
@@ -415,7 +473,7 @@ void Plotter3D::rotate(int dx, int dy)
     GLdouble ax = -dy;
     GLdouble ay = -dx;
     double angle = sqrt(ax*ax + ay*ay)/(m_viewport.width() + 1)*360.0;
-    
+
     if (m_simpleRotation) {
         m_rot.setToIdentity();
         resetViewPrivate(m_simpleRotationVector + QVector3D(ax, 0, ay));
@@ -436,9 +494,9 @@ void Plotter3D::rotate(int dx, int dy)
             QVector3D rot(matrix4.row(0).x()*ax + matrix4.row(1).x()*ay,
                           matrix4.row(0).y()*ax + matrix4.row(1).y()*ay,
                           matrix4.row(0).z()*ax + matrix4.row(1).z()*ay);
-            
+
             m_rot.rotate(rot.length(), rot.normalized());
-            
+
             renderGL();
         }
     }
@@ -471,14 +529,14 @@ void Plotter3D::showAxisArrowHint(CartesianAxis axis)
         return ;
 
     m_currentAxisIndicator = axis;
-    
+
     renderGL();
 }
 
 void Plotter3D::hideAxisHint()
 {
     m_currentAxisIndicator = InvalidAxis;
-    
+
     renderGL();
 }
 
@@ -513,6 +571,7 @@ void Plotter3D::addPlots(PlotItem* item)
 
     if (SpaceCurve *curve = dynamic_cast<SpaceCurve*>(item))
     {
+        Q_UNUSED(curve);
 //         glEnable(GL_LINE_SMOOTH);
 
 //         glLineWidth(2.5);
@@ -520,7 +579,7 @@ void Plotter3D::addPlots(PlotItem* item)
 //         if (m_plottingFocusPolicy == All)
 //             switch (m_plotStyle)
 //             {
-//                 case Solid: 
+//                 case Solid:
 //                 case Wired: glBegin(GL_LINES); break;
 //                 case Dots: glBegin(GL_POINTS); break;
 //             }
@@ -528,16 +587,16 @@ void Plotter3D::addPlots(PlotItem* item)
 //             if (m_plottingFocusPolicy == Current)
 //             {
 //                 QModelIndex pi = m_model->index(currentPlot(), 0);
-// 
+//
 //                 PlotItem* plot = 0;
 //                 if (!pi.isValid())
 //                    plot = pi.data(PlotsModel::PlotRole).value<PlotItem*>();
-// 
+//
 //                 if (plot == curve)
 //                 {
 //                     switch (m_plotStyle)
 //                     {
-//                         case Solid: 
+//                         case Solid:
 //                         case Wired: glBegin(GL_LINES); break;
 //                         case Dots: glBegin(GL_POINTS); break;
 //                     }
@@ -545,27 +604,27 @@ void Plotter3D::addPlots(PlotItem* item)
 //                 else
 //                     glBegin(GL_LINES);
 //             }
-// 
+//
 /*        const QVector<QVector3D> points = curve->points();
-// 
+//
 //         //TODO copy approach from plotter 2d and use jumps optimization
 //         for (int i = 0; i < points.size() -1 ; ++i)
 //         {
 //             glVertex3d(points[i].x(), points[i].y(), points[i].z());
 //             glVertex3d(points[i+1].x(), points[i+1].y(), points[i+1].z());
 //         }
-//         
+//
 //         glEnd();
 //         glDisable(GL_LINE_SMOOTH);
-        
+
         QVector<double> vertices;
         QVector<double> normals;
         indexes.clear();
-        
+
         for (int i = 0; i < points.size(); ++i)
         {
             vertices << points[i].x() << points[i].y() << points[i].z();
-            
+
             if (i%2 != 0)
             {
                 QVector3D n = QVector3D::crossProduct(points[i], points[i-1]).normalized();
@@ -575,7 +634,7 @@ void Plotter3D::addPlots(PlotItem* item)
                 indexes.append(indexes.size());
             }
         }
-                
+
         int bufferSize;
 
         //vertices & normals vbo just allows 1 buffferdata of type array_buffer
@@ -593,18 +652,18 @@ void Plotter3D::addPlots(PlotItem* item)
         glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_itemGeometries[item].first);
         glBufferData(GL_ELEMENT_ARRAY_BUFFER, sizeof(unsigned int)*indexes.size(), indexes.data(), GL_STATIC_DRAW);
         //glGetBufferParameteriv(GL_ELEMENT_ARRAY_BUFFER, GL_BUFFER_SIZE, &bufferSize);
-        //qDebug() << "Index Array in VBO: " << bufferSize << " bytes";  */  
+        //qDebug() << "Index Array in VBO: " << bufferSize << " bytes";  */
     }
     else
     {
         Surface* surf = dynamic_cast<Surface*>(item);
-    
+
         //vertices & normals vbo just allows 1 buffferdata of type array_buffer
         glGenBuffers(1, &m_itemGeometries[item].second);
         glBindBuffer(GL_ARRAY_BUFFER, m_itemGeometries[item].second);
-        glBufferData(GL_ARRAY_BUFFER, sizeof(double)*surf->vertices().size() + sizeof(double)*surf->normals().size(), 0, GL_STREAM_DRAW);
-        glBufferSubData(GL_ARRAY_BUFFER, 0, sizeof(double)*surf->vertices().size(), surf->vertices().data());
-        glBufferSubData(GL_ARRAY_BUFFER, sizeof(double)*surf->vertices().size(), sizeof(double)*surf->normals().size(), surf->normals().data());
+        glBufferData(GL_ARRAY_BUFFER, 3*sizeof(float)*surf->vertices().size() + 3*sizeof(float)*surf->normals().size(), 0, GL_STREAM_DRAW);
+        glBufferSubData(GL_ARRAY_BUFFER, 0, 3*sizeof(float)*surf->vertices().size(), surf->vertices().data());
+        glBufferSubData(GL_ARRAY_BUFFER, 3*sizeof(float)*surf->vertices().size(), 3*sizeof(float)*surf->normals().size(), surf->normals().data());
         //TODO ifdef debug_Graph
         //glGetBufferParameteriv(GL_ARRAY_BUFFER, GL_BUFFER_SIZE, &bufferSize);
         //qDebug() << "Vertex Array in VBO: " << bufferSize << " bytes";
@@ -614,7 +673,7 @@ void Plotter3D::addPlots(PlotItem* item)
         glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_itemGeometries[item].first);
         glBufferData(GL_ELEMENT_ARRAY_BUFFER, sizeof(unsigned int)*surf->indexes().size(), surf->indexes().data(), GL_STATIC_DRAW);
         //glGetBufferParameteriv(GL_ELEMENT_ARRAY_BUFFER, GL_BUFFER_SIZE, &bufferSize);
-        //qDebug() << "Index Array in VBO: " << bufferSize << " bytes";        
+        //qDebug() << "Index Array in VBO: " << bufferSize << " bytes";
 
     }
 }
@@ -638,8 +697,8 @@ void Plotter3D::initAxes()
 {
     const GLubyte XAxisColor[] = {250, 0, 0};
     const GLubyte YAxisColor[] = {0, 255, 0};
-    const GLubyte ZAxisColor[] = {0, 0, 255};    
-    
+    const GLubyte ZAxisColor[] = {0, 0, 255};
+
     if (m_sceneObjects.contains(Axes))
         glDeleteLists(m_sceneObjects.value(Axes), 1);
 
@@ -701,10 +760,7 @@ void Plotter3D::initAxes()
     glEnd();
 
     glEndList();
-    
-    GLUquadricObj *sphereObj;
-    sphereObj = gluNewQuadric();
-    
+
     // XArrowAxisHint
     if (m_sceneObjects.contains(XArrowAxisHint))
         glDeleteLists(m_sceneObjects.value(XArrowAxisHint), 1);
@@ -714,7 +770,6 @@ void Plotter3D::initAxes()
 
     glColor3ub(XAxisArrowColor[0]/2, XAxisArrowColor[1]/2, XAxisArrowColor[2]/2);
     glTranslatef(408.0, 0.0, 0.0);
-    gluSphere(sphereObj, 8.0, 32, 32);
     glTranslatef(-408.0, 0.0, 0.0);
     
     glEndList();
@@ -729,7 +784,6 @@ void Plotter3D::initAxes()
 
     glColor3ub(YAxisArrowColor[0]/2, YAxisArrowColor[1]/2, YAxisArrowColor[2]/2);
     glTranslatef(0.0, 408.0, 0.0);
-    gluSphere(sphereObj, 8.0, 32, 32);
     glTranslatef(0.0, -408.0, 0.0);
 
     glEndList();
@@ -744,7 +798,6 @@ void Plotter3D::initAxes()
 
     glColor3ub(ZAxisArrowColor[0]/2, ZAxisArrowColor[1]/2, ZAxisArrowColor[2]/2);
     glTranslatef(0.0, 0.0, 408.0);
-    gluSphere(sphereObj, 8.0, 32, 32);
     glTranslatef(0.0, 0.0, -408.0);
 
     glEndList();
