@@ -69,7 +69,7 @@ bool Frp::setInterval(const QString& argname, const Analitza::Expression& min, c
     if (min_val<0 || max_val < 0) // el radio es distancia por tanto es positivo, el angulo va de 0 hasta +inf
         return false; 
     
-    if (argname == QString("p") && max_val >= 2*M_PI)
+    if (argname == QStringLiteral("p") && max_val >= 2*M_PI)
         return false;
     
     return AbstractFunctionGraph::setInterval(argname, min, max);
@@ -80,7 +80,7 @@ bool Frp::setInterval(const QString& argname, double min, double max)
     if (min<0 || max < 0) // el radio es distancia por tanto es positivo, el angulo va de 0 hasta +inf
         return false; 
     
-    if (argname == QString("p") && max >= 2*M_PI)
+    if (argname == QStringLiteral("p") && max >= 2*M_PI)
         return false;
     
 
