@@ -180,7 +180,7 @@ void PlaneCurveTest::testParamIntervals()
 
     //Interval as expression
     QVERIFY(f3->setInterval(param, interval_expression.first, interval_expression.second));
-    QCOMPARE(f3->interval(param, true).second.toString(), QString("16"));
+    QCOMPARE(f3->interval(param, true).second.toString(), QStringLiteral("16"));
     
     delete m_vars->take("a");
     delete m_vars->take("b");
